@@ -3,8 +3,6 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from __future__ import print_function
-
 import argparse
 
 from .deprecation import Deprecated
@@ -27,7 +25,8 @@ ARGPARSE_SUPPORTED_KWARGS = [
     'required',
     'help',
     'metavar',
-    'action'
+    'action',
+    'default_value_source'
 ]
 
 
@@ -108,7 +107,7 @@ class CLICommandParser(argparse.ArgumentParser):
         # or description for a command. We better stash it away before handing it off for
         # "normal" argparse handling...
         self._description = kwargs.pop('description', None)
-        super(CLICommandParser, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def load_command_table(self, command_loader):
         """ Process the command table and load it into the parser
@@ -173,6 +172,8 @@ class CLICommandParser(argparse.ArgumentParser):
                 param.completer = arg.completer
                 param.deprecate_info = arg.deprecate_info
                 param.preview_info = arg.preview_info
+                param.experimental_info = arg.experimental_info
+                param.default_value_source = arg.default_value_source
             command_parser.set_defaults(
                 func=metadata,
                 command=command_name,
@@ -220,7 +221,7 @@ class CLICommandParser(argparse.ArgumentParser):
         return parent_subparser
 
     def validation_error(self, message):
-        return super(CLICommandParser, self).error(message)
+        return super().error(message)
 
     def is_group(self):
         """ Determine if this parser instance represents a group
@@ -256,7 +257,7 @@ class CLICommandParser(argparse.ArgumentParser):
         by ArgumentParser.parse_args as usual
         """
         self._expand_prefixed_files(args)
-        return super(CLICommandParser, self).parse_args(args)
+        return super().parse_args(args)
 
     def _check_value(self, action, value):
         # Override to customize the error message when a argument is not among the available choices
