@@ -3,19 +3,16 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from __future__ import unicode_literals
-
 import unittest
 try:
     import mock
 except ImportError:
     from unittest import mock
-from threading import Lock
 
 from knack.arguments import ArgumentsContext
-from knack.commands import CLICommand, CLICommandsLoader, CommandGroup
+from knack.commands import CLICommandsLoader, CommandGroup
 
-from tests.util import DummyCLI, redirect_io
+from tests.util import DummyCLI, redirect_io, assert_in_multi_line, disable_color
 
 
 def example_handler(arg1, arg2=None, arg3=None):
@@ -37,7 +34,7 @@ class TestCommandDeprecation(unittest.TestCase):
 
         class DeprecationTestCommandLoader(CLICommandsLoader):
             def load_command_table(self, args):
-                super(DeprecationTestCommandLoader, self).load_command_table(args)
+                super().load_command_table(args)
                 with CommandGroup(self, '', '{}#{{}}'.format(__name__)) as g:
                     g.command('cmd1', 'example_handler', deprecate_info=g.deprecate(redirect='alt-cmd1'))
                     g.command('cmd2', 'example_handler', deprecate_info=g.deprecate(redirect='alt-cmd2', hide='1.0.0'))
@@ -55,7 +52,7 @@ class TestCommandDeprecation(unittest.TestCase):
                     c.argument('arg1', options_list=['--arg', '-a'], required=False, type=int, choices=[1, 2, 3])
                     c.argument('arg2', options_list=['-b'], required=True, choices=['a', 'b', 'c'])
 
-                super(DeprecationTestCommandLoader, self).load_arguments(command)
+                super().load_arguments(command)
 
         helps['grp1'] = """
     type: group
@@ -82,7 +79,7 @@ Commands:
     cmd4 [Deprecated] : Short summary here.
 
 """.format(self.cli_ctx.name)
-        self.assertEqual(expected, actual)
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_deprecate_command_help_hidden(self):
@@ -93,15 +90,16 @@ Commands:
         expected = """
 Command
     {} cmd3 : Short summary here.
-        Long summary here. Still long summary. This command has been deprecated and will be
-        removed in a future release. Use 'alt-cmd3' instead.
+        Long summary here. Still long summary.
+        This command has been deprecated and will be removed in a future release. Use 'alt-
+        cmd3' instead.
 
 Arguments
-    -b [Required] : Allowed values: a, b, c.
-    --arg -a      : Allowed values: 1, 2, 3.
+    -b      [Required] : Allowed values: a, b, c.
+    --arg -a           : Allowed values: 1, 2, 3.
     --arg3
 """.format(self.cli_ctx.name)
-        self.assertIn(expected, actual)
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_deprecate_command_plain_execute(self):
@@ -127,13 +125,32 @@ Arguments
         expected = "This command has been deprecated and will be removed in version '1.0.0'. Use 'alt-cmd4' instead."
         self.assertIn(expected, actual)
 
+    @redirect_io
+    def test_deprecate_command_expiring_execute_no_color(self):
+        """ Ensure warning is displayed without color. """
+        self.cli_ctx.enable_color = False
+        self.cli_ctx.invoke('cmd4 -b b'.split())
+        actual = self.io.getvalue()
+        expected = "WARNING: This command has been deprecated and will be removed in version '1.0.0'"
+        self.assertIn(expected, actual)
+
     @redirect_io
     def test_deprecate_command_expired_execute(self):
         """ Ensure expired command cannot be reached. """
         with self.assertRaises(SystemExit):
             self.cli_ctx.invoke('cmd5 -h'.split())
         actual = self.io.getvalue()
-        expected = """The most similar choices to 'cmd5'"""
+        expected = """cli: 'cmd5' is not in the 'cli' command group."""
+        self.assertIn(expected, actual)
+
+    @redirect_io
+    @disable_color
+    def test_deprecate_command_expired_execute_no_color(self):
+        """ Ensure error is displayed without color. """
+        with self.assertRaises(SystemExit):
+            self.cli_ctx.invoke('cmd5 -h'.split())
+        actual = self.io.getvalue()
+        expected = """ERROR: cli: 'cmd5' is not in the 'cli' command group."""
         self.assertIn(expected, actual)
 
 
@@ -145,7 +162,7 @@ class TestCommandGroupDeprecation(unittest.TestCase):
 
         class DeprecationTestCommandLoader(CLICommandsLoader):
             def load_command_table(self, args):
-                super(DeprecationTestCommandLoader, self).load_command_table(args)
+                super().load_command_table(args)
 
                 with CommandGroup(self, 'group1', '{}#{{}}'.format(__name__), deprecate_info=self.deprecate(redirect='alt-group1')) as g:
                     g.command('cmd1', 'example_handler')
@@ -169,7 +186,7 @@ class TestCommandGroupDeprecation(unittest.TestCase):
                     c.argument('arg1', options_list=['--arg', '-a'], required=False, type=int, choices=[1, 2, 3])
                     c.argument('arg2', options_list=['-b'], required=True, choices=['a', 'b', 'c'])
 
-                super(DeprecationTestCommandLoader, self).load_arguments(command)
+                super().load_arguments(command)
 
         helps['group1'] = """
     type: group
@@ -193,7 +210,7 @@ Commands:
     cmd1 : Short summary here.
 
 """.format(self.cli_ctx.name)
-        self.assertEqual(expected, actual)
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_deprecate_command_group_help_hidden(self):
@@ -211,7 +228,7 @@ Commands:
     cmd1 : Short summary here.
 
 """.format(self.cli_ctx.name)
-        self.assertIn(expected, actual)
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_deprecate_command_group_help_expiring(self):
@@ -224,6 +241,21 @@ Group
     {} group4
         This command group has been deprecated and will be removed in version '1.0.0'. Use
         'alt-group4' instead.
+""".format(self.cli_ctx.name)
+        assert_in_multi_line(expected, actual)
+
+    @redirect_io
+    @disable_color
+    def test_deprecate_command_group_help_expiring_no_color(self):
+        """ Ensure warning is displayed without color. """
+        with self.assertRaises(SystemExit):
+            self.cli_ctx.invoke('group4 -h'.split())
+        actual = self.io.getvalue()
+        expected = """
+Group
+    cli group4
+        WARNING: This command group has been deprecated and will be removed in version \'1.0.0\'. Use
+        'alt-group4' instead.
 """.format(self.cli_ctx.name)
         self.assertIn(expected, actual)
 
@@ -245,11 +277,11 @@ Group
         expected = """
 Command
     {} group1 cmd1 : Short summary here.
-        Long summary here. Still long summary. This command is implicitly deprecated because
-        command group 'group1' is deprecated and will be removed in a future release. Use 'alt-
-        group1' instead.
+        Long summary here. Still long summary.
+        This command is implicitly deprecated because command group 'group1' is deprecated and
+        will be removed in a future release. Use 'alt-group1' instead.
 """.format(self.cli_ctx.name)
-        self.assertIn(expected, actual)
+        assert_in_multi_line(expected, actual)
 
 
 class TestArgumentDeprecation(unittest.TestCase):
@@ -260,7 +292,7 @@ class TestArgumentDeprecation(unittest.TestCase):
 
         class DeprecationTestCommandLoader(CLICommandsLoader):
             def load_command_table(self, args):
-                super(DeprecationTestCommandLoader, self).load_command_table(args)
+                super().load_command_table(args)
                 with CommandGroup(self, '', '{}#{{}}'.format(__name__)) as g:
                     g.command('arg-test', 'example_arg_handler')
                 return self.command_table
@@ -278,7 +310,7 @@ class TestArgumentDeprecation(unittest.TestCase):
                     c.argument('arg5', deprecate_info=c.deprecate(expiration='0.1.0'))
                     c.argument('opt5', options_list=['--opt5', c.deprecate(redirect='--opt5', target='--alt5', expiration='0.1.0')])
 
-                super(DeprecationTestCommandLoader, self).load_arguments(command)
+                super().load_arguments(command)
 
         helps['grp1'] = """
     type: group
@@ -319,7 +351,7 @@ Arguments
     --opt4
     --opt5
 """.format(self.cli_ctx.name)
-        self.assertTrue(actual.startswith(expected))
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_deprecate_arguments_execute(self):
@@ -410,6 +442,15 @@ Arguments
         expected = "Option '--alt4' has been deprecated and will be removed in version '1.0.0'. Use '--opt4' instead."
         self.assertIn(expected, actual)
 
+    @redirect_io
+    @disable_color
+    def test_deprecate_options_execute_expiring_no_color(self):
+        """ Ensure error is displayed without color. """
+        self.cli_ctx.invoke('arg-test --arg1 foo --opt1 bar --alt4 bar'.split())
+        actual = self.io.getvalue()
+        expected = "WARNING: Option '--alt4' has been deprecated and will be removed in version '1.0.0'. Use '--opt4' instead."
+        self.assertIn(expected, actual)
+
     @redirect_io
     def test_deprecate_options_execute_expiring_non_deprecated(self):
         """ Ensure non-expiring options can be used without warning. """
